
;**********************************************************************
; Packets are defined as either OUTPUT (0x40-0x7F) or INPUT (0x80-0xBF).
;
; Output packets are those that are sent from the sensor to the receiver
; and input packets are those that are sent from the receiver to the
; sensor.
;
;
; OUTPUT PACKETS:
;
;
; 0x40 - Not defined
;
; Not defined.
;
; Output: Command (0x40), Device ID (DevID),  , CRC
;
;----------------------------------------------------------------------
; 0x41 - Request Device ID
;
; Sent to request a device ID assignment by the receiver.  This is used during
; the initialization mode.
;
; Output: Command (0x41), Device ID (0xFF), Length (1), Class, CRC
;
;----------------------------------------------------------------------
; 0x42 - Send Sensor Data
;
; Sensor data is sent to the receiver in response to a request (0x82).
;
; Output: Command (0x42), Device ID (DevID), Length (3+X), Class (X),
; Output Type (X), Output Format (X), (X) Data Bytes, CRC
;
;----------------------------------------------------------------------
; 0x43 - Send Vendor Info
;
; The sensor's vendor information string is sent to the receiver in
; response to a request (0x83).
;
; Output: Command (0x43), Device ID (DevID), Length (X), Data Bytes * X, CRC
;
;----------------------------------------------------------------------
; 0x44 - Send Sensor Settings
;
; The sensor's custom settings are sent to the receiver in response to
; a request (0x84).
;
; Output: Command (0x44), Device ID (DevID), Length (X), X bytes of data, CRC
;
;
;______________________________________________________________________
;
; INPUT PACKETS:
;
;
; 0x80 - Init Mode
;
; This command puts the sensor into initialization mode, required to
; obtain a device ID from the receiver.  The device ID is used when
; communicating.
;
; Input: Command (0x80), Device ID (0xFF), Length (0), Checksum (CRC)
; Output: None
;
;----------------------------------------------------------------------
; 0x81 - Assign Device ID
;
; This packet contains the Device ID that is to be used to distinguish
; the sensor from any others during communications.  The number of
; requests per second for the sensor is also set.
;
; Input: Command (0x81), Device ID (DevID), Length (1), Requests per second, CRC
; Output: None
;
;----------------------------------------------------------------------
; 0x82 - Request Sensor Data
;
; This packet requests the sensor's data to be sent.
;
; Input: Command (0x82), Device ID (DevID), Length (0), CRC
; Output: Command (0x42), Device ID (DevID), Length (3+X), Class (X),
; Output Type (X), Output Format (X), (X) Data Bytes, CRC
;
;----------------------------------------------------------------------
; 0x83 - Request Vendor Info
;
; This packet requests the information about the sensor (typically
; the vendor ID string).
;
; Input: Command (0x83), Device ID (DevID), Length (0), CRC
; Output: Command (0x43), Device ID (DevID), Length (X), String Bytes * X, CRC
;
;----------------------------------------------------------------------
; 0x84 - Request Sensor Settings
;
; This packet requests the sensors custom setting.
;
; Input: Command (0x84), Device ID (DevID), Length (0), CRC
; Output: Command (0x44), Device ID (DevID), Length (X), X bytes of data, CRC
;
;----------------------------------------------------------------------
; 0x85 - Set Sensor Settings
;
; This packet sets the sensors custom settings.
;
; Input: Command (0x85), Device ID (DevID), Length (X), X bytes of data, CRC
; Output: None
;
;______________________________________________________________________


;---------------------------------------------------------------
; Telemetry types/classes
; 

; 0x00-0x0F  Voltage class

tc_vBattery1	EQU	0x00				; Battery 1 voltage
tc_vBattery2	EQU	0x01				; Battery 2 voltage
tc_vBattery3	EQU	0x02				; Battery 3 voltage
tc_vBattery4	EQU	0x03				; Battery 4 voltage
tc_vMotor1	EQU	0x04				; Motor supply 1 voltage
tc_vMotor2	EQU	0x05				; Motor supply 2 voltage
tc_vMotor3	EQU	0x06				; Motor supply 3 voltage
tc_vMotor4	EQU	0x07				; Motor supply 4 voltage

;	   0x08-0x0F	Not defined

; 0x10-0x1F  Amperage (current) class

tc_cMotor1	EQU	0x10				; Motor 1 amperage
tc_cMotor2	EQU	0x11				; Motor 2 amperage
tc_cMotor3	EQU	0x12				; Motor 3 amperage
tc_cMotor4	EQU	0x13				; Motor 4 amperage
tc_cServo1	EQU	0x14				; Servo 1 amperage
tc_cServo2	EQU	0x15				; Servo 2 amperage
tc_cServo3	EQU	0x16				; Servo 3 amperage
tc_cServo4	EQU	0x17				; Servo 4 amperage
tc_cServo5	EQU	0x18				; Servo 5 amperage
tc_cServo6	EQU	0x19				; Servo 6 amperage
tc_cServo7	EQU	0x1A				; Servo 7 amperage
tc_cServo8	EQU	0x1B				; Servo 8 amperage
tc_cMisc1	EQU	0x1C				; Misc. 1 amperage
tc_cMisc2	EQU	0x1D				; Misc. 2 amperage
tc_cMisc3	EQU	0x1E				; Misc. 3 amperage
tc_cMisc4	EQU	0x1F				; Misc. 4 amperage

; 0x20-0x2F  Temperature class

tc_tAmbient	EQU	0x20				; Ambient temperaure
tc_tExternal1	EQU	0x21				; External 1 temperaure
tc_tExternal2	EQU	0x22				; External 2 temperaure
tc_tMotor1	EQU	0x23				; Motor 1/Engine 1 temperaure
tc_tMotor2	EQU	0x24				; Motor 2/Engine 2 temperaure
tc_tMotor3	EQU	0x25				; Motor 3/Engine 3 temperaure
tc_tMotor4	EQU	0x26				; Motor 4/Engine 4 temperaure
tc_tEGT1	EQU	0x27				; EGT 1 temperaure
tc_tEGT2	EQU	0x28				; EGT 2 temperaure
tc_tEGT3	EQU	0x29				; EGT 3 temperaure
tc_tEGT4	EQU	0x2A				; EGT 4 temperaure
tc_tBattery1	EQU	0x2B				; Battery 1 temperaure
tc_tBattery2	EQU	0x2C				; Battery 2 temperaure
tc_tBattery3	EQU	0x2D				; Battery 3 temperaure
tc_tBattery4	EQU	0x2E				; Battery 4 temperaure
tc_tMisc1	EQU	0x2F				; Misc. 1 temperaure

; 0x30-0x3F  Pressure class

tc_pAirTank1	EQU	0x30				; Air tank 1 pressure
tc_pAirTank2	EQU	0x31				; Air tank 2 pressure
tc_pAirTank3	EQU	0x32				; Air tank 3 pressure
tc_pAirTank4	EQU	0x33				; Air tank 4 pressure
tc_pRetract1	EQU	0x34				; Retract 1 pressure
tc_pRetract2	EQU	0x35				; Retract 2 pressure
tc_pRetract3	EQU	0x36				; Retract 3 pressure
tc_pRetract4	EQU	0x37				; Retract 4 pressure
tc_pBrake1	EQU	0x38				; Brake 1 pressure
tc_pBrake2	EQU	0x39				; Brake 2 pressure
tc_pBrake3	EQU	0x3A				; Brake 3 pressure
tc_pBrake4	EQU	0x3B				; Brake 4 pressure
tc_pMisc1	EQU	0x3C				; Misc. 1 pressure
tc_pMisc2	EQU	0x3D				; Misc. 2 pressure
tc_pMisc3	EQU	0x3E				; Misc. 3 pressure
tc_pMisc4	EQU	0x3F				; Misc. 4 pressure

; 0x40-0x4F  Level class (liquid level)

tc_lFuelTank1	EQU	0x40				; Fuel tank 1 level
tc_lFuelTank2	EQU	0x41				; Fuel tank 2 level
tc_lFuelTank3	EQU	0x42				; Fuel tank 3 level
tc_lFuelTank4	EQU	0x43				; Fuel tank 4 level
tc_lSmokeTank1	EQU	0x44				; Smoke tank 1 level
tc_lSmokeTank2	EQU	0x45				; Smoke tank 2 level

;	   0x46-0x4F	Not defined


; 0x50-0x5F  G-Force class

tc_mXAxis	EQU	0x50				; X-axis g-force
tc_mYAxis	EQU	0x51				; Y-axis g-force
tc_mZAxis	EQU	0x52				; Z-axis g-force

;	   0x53-0x5F	Not defined


; 0x60-0x6F  Position class

tc_zSlider1	EQU	0x60				; Slider 1 position
tc_zSlider2	EQU	0x61				; Slider 2 position
tc_zSlider3	EQU	0x62				; Slider 3 position
tc_zSlider4	EQU	0x63				; Slider 4 position

;	   0x64-0x6F	Not defined

; 0x70-0x7F  Altitude class

tc_aAltitude1	EQU	0x70				; Altitude 1
tc_aAltitude2	EQU	0x71				; Altitude 2
tc_aAltitude3	EQU	0x72				; Altitude 3
tc_aAltitude4	EQU	0x73				; Altitude 4

;	   0x74-0x7F	Not defined

; 0x80-0x8F  Speed class

tc_sAirspeed1	EQU	0x80				; Air speed 1
tc_sAirspeed2	EQU	0x81				; Air speed 2
tc_sAirspeed3	EQU	0x82				; Air speed 3
tc_sAirspeed4	EQU	0x83				; Air speed 4
tc_sHalleSpeed1	EQU	0x84				; hall speed 1
tc_sHalleSpeed2	EQU	0x85				; hall speed 2
tc_sHalleSpeed3	EQU	0x86				; hall speed 3
tc_sHalleSpeed4	EQU	0x87				; hall speed 4
tc_sEncSpeed1	EQU	0x88				; Encoder Speed 1
tc_sEncSpeed2	EQU	0x89				; Encoder Speed 2
tc_sEncSpeed3	EQU	0x8A				; Encoder Speed 3
tc_sEncSpeed4	EQU	0x8B				; Encoder Speed 4
tc_sMisc1	EQU	0x8C				; Misc. 1 speed
tc_sMisc2	EQU	0x8D				; Misc. 2 speed
tc_sMisc3	EQU	0x8E				; Misc. 3 speed
tc_sMisc4	EQU	0x8F				; Misc. 4 speed

; 0x90-0x9F  GPS class

tc_gGPS1	EQU	0x90				; GPS1
tc_gGPS2	EQU	0x91				; GPS2

;	   0x92-0x9F	Not defined

; 0xA0-0xAF  RPM class

tc_rMotor1	EQU	0xA0				; Motor 1/Engine 1 RPM
tc_rMotor2	EQU	0xA1				; Motor 1/Engine 2 RPM
tc_rMotor3	EQU	0xA2				; Motor 1/Engine 3 RPM
tc_rMotor4	EQU	0xA3				; Motor 1/Engine 4 RPM

;	   0xA4-0xAF	Not defined

; 0xD0-0xDF Lock class

tc_fGear	EQU	0xD0				; Gear lock
tc_fGeadDoor1	EQU	0xD1				; Gear door 1 lock
tc_fGeadDoor2	EQU	0xD2				; Gear door 2 lock
tc_fGeadDoor3	EQU	0xD3				; Gear door 3 lock
tc_fGeadDoor4	EQU	0xD4				; Gear door 4 lock
tc_fGeadDoor5	EQU	0xD5				; Gear door 5 lock
tc_fGeadDoor6	EQU	0xD6				; Gear door 6 lock
tc_fCanopy	EQU	0xD7				; Canopy
tc_fTopHatch	EQU	0xD8				; Top hatch
tc_fBottomHatch	EQU	0xD9				; Bottom hatch

;	   0xDA-0xDF	Not defined

; 0xE0-0xEF Special class

tc_xGSU		EQU	0xE0				; Turbine GSU Display
tc_xStall	EQU	0xE1				; Stall sensor
tc_xAttitude	EQU	0xE2				; Attitude sensor

;	   0xE3-0xEF	Not defined

; 0xF0-0xFF  XPS only

